==> ugene_34.0+dfsg.orig.tar.xz: ugene-34.0/src/plugins/dna_flexibility/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>DNAFlexDialog</name>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="26"/>
        <source>DNA Flexibility</source>
        <translation>ДНК гибкость</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="32"/>
        <source>The DNA Flexibility plugin allows searching for high DNA flexibility regions.</source>
        <translation>Модуль &quot;ДНК гибкость&quot; позволяет искать в ДНК районы повышенной гибкости.</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="51"/>
        <source>Search Settings</source>
        <translation>Параметры поиска</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="63"/>
        <source>High DNA Flexibility Regions Settings</source>
        <translation>Параметры районов повышенной гибкости</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="71"/>
        <source>Window size</source>
        <translation>Размер окна</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="94"/>
        <source>Window step</source>
        <translation>Шаг</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="114"/>
        <source>Threshold</source>
        <translation>Пороговая величина</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="140"/>
        <source>Remember Settings</source>
        <translation>Запомнить настройки</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="147"/>
        <source>Restore Defaults</source>
        <translation>Настройки по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="160"/>
        <source>Output</source>
        <translation>Выходные параметры</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/HighFlexSettings.cpp" line="89"/>
        <source>Invalid high flex setting window size is stored in the application settings.</source>
        <translation>Настройки приложения содержат некорректный параметр window size.</translation>
    </message>
    <message>
        <location filename="../src/HighFlexSettings.cpp" line="101"/>
        <source>Invalid high flex setting window step is stored in the application settings.</source>
        <translation>Настройки приложения содержат некорректный параметр window step.</translation>
    </message>
    <message>
        <location filename="../src/HighFlexSettings.cpp" line="113"/>
        <source>Invalid high flex setting threshold is stored in the application settings.</source>
        <translation>Настройки приложения содержат некорректный параметр threshold.</translation>
    </message>
</context>
<context>
    <name>U2::DNAFlexDialog</name>
    <message>
        <location filename="../src/DNAFlexDialog.cpp" line="45"/>
        <source>Search</source>
        <translation>Искать</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.cpp" line="100"/>
        <location filename="../src/DNAFlexDialog.cpp" line="105"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.cpp" line="105"/>
        <source>Cannot create an annotation object. Please check settings</source>
        <translation>Невозможно создать аннотацию. Проверьте настройки</translation>
    </message>
</context>
<context>
    <name>U2::DNAFlexGraphFactory</name>
    <message>
        <location filename="../src/DNAFlexGraph.cpp" line="43"/>
        <source>DNA Flexibility</source>
        <translation>ДНК гибкость</translation>
    </message>
</context>
<context>
    <name>U2::DNAFlexPlugin</name>
    <message>
        <location filename="../src/DNAFlexPlugin.cpp" line="49"/>
        <source>DNA Flexibility</source>
        <translation>ДНК гибкость</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexPlugin.cpp" line="50"/>
        <source>Searches a DNA sequence for regions of high DNA helix flexibility.</source>
        <translation>Позволяет искать в ДНК районы высокой флексибильности.</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexGraphAlgorithm.cpp" line="73"/>
        <source>UGENE ran out of memory during the DNA flexibility calculating. The 32-bit UGENE version has a restriction on its memory consumption. Try using the 64-bit version instead.</source>
        <translation>UGENE ran out of memory during the DNA flexibility calculating. The 32-bit UGENE version has a restriction on its memory consumption. Try using the 64-bit version instead.</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexGraphAlgorithm.cpp" line="76"/>
        <source>Out of memory during the DNA flexibility calculating.</source>
        <translation>Out of memory during the DNA flexibility calculating.</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexGraphAlgorithm.cpp" line="79"/>
        <source>Internal error occurred during the DNA flexibility calculating.</source>
        <translation>Internal error occurred during the DNA flexibility calculating.</translation>
    </message>
</context>
<context>
    <name>U2::DNAFlexTask</name>
    <message>
        <location filename="../src/DNAFlexTask.cpp" line="44"/>
        <source>DNA Flexibility task</source>
        <translation>Задача анализа ДНК флексибильности</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexTask.cpp" line="67"/>
        <source>The annotations object is not available!</source>
        <translation>Недоступен объект аннотаций!</translation>
    </message>
</context>
<context>
    <name>U2::DNAFlexViewContext</name>
    <message>
        <location filename="../src/DNAFlexPlugin.cpp" line="90"/>
        <source>Unsupported sequence alphabet, only standard DNA alphabet is supported</source>
        <translation>Неподдерживаемый алфавит, входная последовательность должна состоять из букв A, C, G и T</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexPlugin.cpp" line="113"/>
        <source>Find high DNA flexibility regions...</source>
        <translation>Поиск участков ДНК с повышенной гибкостью...</translation>
    </message>
</context>
<context>
    <name>U2::FindHighFlexRegions</name>
    <message>
        <location filename="../src/FindHighFlexRegions.cpp" line="33"/>
        <source>Searching for regions of high DNA flexibility</source>
        <translation>Поиск районов высокой флексибильности</translation>
    </message>
</context>
</TS>

==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/plugins/dna_flexibility/transl/russian.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>DNAFlexDialog</name>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="26"/>
        <source>DNA Flexibility</source>
        <translation>ДНК гибкость</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="32"/>
        <source>The DNA Flexibility plugin allows searching for high DNA flexibility regions.</source>
        <translation>Модуль &quot;ДНК гибкость&quot; позволяет искать в ДНК районы повышенной гибкости.</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="51"/>
        <source>Search Settings</source>
        <translation>Параметры поиска</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="63"/>
        <source>High DNA Flexibility Regions Settings</source>
        <translation>Параметры районов повышенной гибкости</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="71"/>
        <source>Window size</source>
        <translation>Размер окна</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="94"/>
        <source>Window step</source>
        <translation>Шаг</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="114"/>
        <source>Threshold</source>
        <translation>Пороговая величина</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="140"/>
        <source>Remember Settings</source>
        <translation>Запомнить настройки</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="147"/>
        <source>Restore Defaults</source>
        <translation>Настройки по умолчанию</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.ui" line="160"/>
        <source>Output</source>
        <translation>Выходные параметры</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/HighFlexSettings.cpp" line="78"/>
        <source>Invalid high flex setting window size is stored in the application settings.</source>
        <translation>Настройки приложения содержат некорректный параметр window size.</translation>
    </message>
    <message>
        <location filename="../src/HighFlexSettings.cpp" line="89"/>
        <source>Invalid high flex setting window step is stored in the application settings.</source>
        <translation>Настройки приложения содержат некорректный параметр window step.</translation>
    </message>
    <message>
        <location filename="../src/HighFlexSettings.cpp" line="100"/>
        <source>Invalid high flex setting threshold is stored in the application settings.</source>
        <translation>Настройки приложения содержат некорректный параметр threshold.</translation>
    </message>
</context>
<context>
    <name>U2::DNAFlexDialog</name>
    <message>
        <location filename="../src/DNAFlexDialog.cpp" line="47"/>
        <source>Search</source>
        <translation>Искать</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.cpp" line="48"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.cpp" line="101"/>
        <location filename="../src/DNAFlexDialog.cpp" line="106"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexDialog.cpp" line="106"/>
        <source>Cannot create an annotation object. Please check settings</source>
        <translation>Невозможно создать аннотацию. Проверьте настройки</translation>
    </message>
</context>
<context>
    <name>U2::DNAFlexGraphFactory</name>
    <message>
        <location filename="../src/DNAFlexGraph.cpp" line="40"/>
        <source>DNA Flexibility</source>
        <translation>ДНК гибкость</translation>
    </message>
</context>
<context>
    <name>U2::DNAFlexPlugin</name>
    <message>
        <location filename="../src/DNAFlexPlugin.cpp" line="48"/>
        <source>DNA Flexibility</source>
        <translation>ДНК гибкость</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexPlugin.cpp" line="49"/>
        <source>Searches a DNA sequence for regions of high DNA helix flexibility.</source>
        <translation>Позволяет искать в ДНК районы высокой флексибильности.</translation>
    </message>
    <message>
        <source>UGENE ran out of memory during the DNA flexibility calculating. The 32-bit UGENE version has a restriction on its memory consumption. Try using the 64-bit version instead.</source>
        <translation type="vanished">UGENE ran out of memory during the DNA flexibility calculating. The 32-bit UGENE version has a restriction on its memory consumption. Try using the 64-bit version instead.</translation>
    </message>
    <message>
        <source>Out of memory during the DNA flexibility calculating.</source>
        <translation type="vanished">Out of memory during the DNA flexibility calculating.</translation>
    </message>
    <message>
        <source>Internal error occurred during the DNA flexibility calculating.</source>
        <translation type="vanished">Internal error occurred during the DNA flexibility calculating.</translation>
    </message>
</context>
<context>
    <name>U2::DNAFlexTask</name>
    <message>
        <location filename="../src/DNAFlexTask.cpp" line="45"/>
        <source>DNA Flexibility task</source>
        <translation>Задача анализа ДНК флексибильности</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexTask.cpp" line="67"/>
        <source>The annotations object is not available!</source>
        <translation>Недоступен объект аннотаций!</translation>
    </message>
</context>
<context>
    <name>U2::DNAFlexViewContext</name>
    <message>
        <location filename="../src/DNAFlexPlugin.cpp" line="79"/>
        <source>Unsupported sequence alphabet, only standard DNA alphabet is supported</source>
        <translation>Неподдерживаемый алфавит, входная последовательность должна состоять из букв A, C, G и T</translation>
    </message>
    <message>
        <location filename="../src/DNAFlexPlugin.cpp" line="99"/>
        <source>Find high DNA flexibility regions...</source>
        <translation>Поиск участков ДНК с повышенной гибкостью...</translation>
    </message>
</context>
<context>
    <name>U2::FindHighFlexRegions</name>
    <message>
        <location filename="../src/FindHighFlexRegions.cpp" line="31"/>
        <source>Searching for regions of high DNA flexibility</source>
        <translation>Поиск районов высокой флексибильности</translation>
    </message>
</context>
</TS>
